import { renderless, api } from '@opentinyvue/vue-renderless/transfer/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Button from '@opentinyvue/vue-button';
import TransferPanel from '@opentinyvue/vue-transfer-panel';
import { iconDoubleLeft, iconChevronLeft, iconChevronRight, iconDoubleRight } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/transfer/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    TinyTransferPanel: TransferPanel,
    IconDoubleLeft: iconDoubleLeft(),
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight(),
    IconDoubleRight: iconDoubleRight()
  },
  props: [].concat(props, ["data", "titles", "buttonTexts", "filterPlaceholder", "filterMethod", "leftDefaultChecked", "rightDefaultChecked", "renderContent", "modelValue", "format", "filterable", "props", "targetOrder", "dropConfig", "showAllBtn", "toLeftDisable", "toRightDisable", "renderType", "leftColumns", "rightColumns", "columns", "pageVO", "pagerOp", "showPager", "render", "treeOp", "beforeTransfer", "panelStyle", "panelBodyStyle", "panelTableHeight"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-transfer",
    style: _vm.panelTableHeight ? {
      "--tv-Transfer-table-dyn-height": _vm.panelTableHeight
    } : {}
  }, [!_vm.slots["right-panel"] && !_vm.slots["left-panel"] ? _c("tiny-transfer-panel", _vm._b({
    ref: "leftPanel",
    attrs: {
      "id": "leftPanel",
      "option-render": _vm.state.optionRender,
      "tree-op": _vm.treeOp,
      "render": _vm.render,
      "show-pager": _vm.showPager,
      "pager-op": _vm.pagerOp,
      "page-v-o": _vm.pageVO,
      "render-type": _vm.renderType,
      "columns": _vm.leftColumns || _vm.columns,
      "data": _vm.state.sourceData,
      "title": _vm.titles[0] || _vm.t("ui.transfer.titles.0"),
      "default-checked": _vm.leftDefaultChecked,
      "placeholder": _vm.filterPlaceholder || _vm.t("ui.transfer.filterPlaceholder"),
      "show-left": true
    },
    on: {
      "checked-change": _vm.onSourceCheckedChange
    }
  }, "tiny-transfer-panel", _vm.$props, false), [_vm._t("left-footer"), _vm._t("filter")], 2) : _vm._e(), _vm.slots["left-panel"] && _vm.slots["right-panel"] ? _c("div", {
    staticClass: "tiny-transfer-panel transfer-custom-left-panel"
  }, [_vm._t("left-panel")], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-transfer__buttons"
  }, [_vm._t("button-panel", function() {
    return [_vm.showAllBtn ? _c("tiny-button", {
      staticClass: "tiny-transfer__button",
      attrs: {
        "type": "primary",
        "disabled": _vm.state.leftData.length === 0
      },
      on: {
        "click": function click($event) {
          return _vm.addToRight("all");
        }
      }
    }, [_c("icon-double-right", {
      staticClass: "tiny-svg-size"
    })], 1) : _vm._e(), _c("div", {
      staticClass: "defaultButton"
    }, [_c("tiny-button", {
      class: ["tiny-transfer__button", _vm.state.hasButtonTexts ? "is-with-texts" : ""],
      attrs: {
        "type": "primary",
        "disabled": _vm.state.isToLeftBtnDisabled
      },
      on: {
        "click": _vm.addToRight
      }
    }, [_vm.buttonTexts[1] !== void 0 ? _c("span", [_vm._v(_vm._s(_vm.buttonTexts[1]))]) : _vm._e(), _c("icon-chevron-right", {
      staticClass: "tiny-svg-size"
    })], 1), _c("tiny-button", {
      class: ["tiny-transfer__button", _vm.state.hasButtonTexts ? "is-with-texts" : ""],
      attrs: {
        "type": "primary",
        "disabled": _vm.toRightDisable && _vm.state.rightChecked.length === 0
      },
      on: {
        "click": _vm.addToLeft
      }
    }, [_c("icon-chevron-left", {
      staticClass: "tiny-svg-size"
    }), _vm.buttonTexts[0] !== void 0 ? _c("span", [_vm._v(_vm._s(_vm.buttonTexts[0]))]) : _vm._e()], 1)], 1), _vm.showAllBtn ? _c("tiny-button", {
      staticClass: "tiny-transfer__button",
      attrs: {
        "type": "primary",
        "disabled": _vm.state.rightData.length === 0
      },
      on: {
        "click": function click($event) {
          return _vm.addToLeft("all");
        }
      }
    }, [_c("icon-double-left", {
      staticClass: "tiny-svg-size"
    })], 1) : _vm._e()];
  })], 2), !_vm.slots["right-panel"] && !_vm.slots["left-panel"] ? _c("tiny-transfer-panel", _vm._b({
    ref: "rightPanel",
    attrs: {
      "id": "rightPanel",
      "render": _vm.render,
      "option-render": _vm.state.optionRender,
      "tree-op": _vm.treeOp,
      "show-pager": _vm.showPager,
      "is-to-left": _vm.state.isToLeft,
      "pager-op": _vm.pagerOp,
      "page-v-o": _vm.pageVO,
      "render-type": _vm.renderType,
      "columns": _vm.rightColumns || _vm.columns,
      "data": _vm.state.targetData,
      "title": _vm.titles[1] || _vm.t("ui.transfer.titles.1"),
      "default-checked": _vm.rightDefaultChecked,
      "placeholder": _vm.filterPlaceholder || _vm.t("ui.transfer.filterPlaceholder"),
      "show-left": false
    },
    on: {
      "checked-change": _vm.onTargetCheckedChange
    }
  }, "tiny-transfer-panel", _vm.$props, false), [_vm._t("right-footer"), _vm._t("filter")], 2) : _vm._e(), _vm.slots["left-panel"] && _vm.slots["right-panel"] ? _c("div", {
    staticClass: "tiny-transfer-panel transfer-custom-right-panel"
  }, [_vm._t("right-panel")], 2) : _vm._e()], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
